@@ -186,9 +186,13 @@ def is_glvnd():
 
 def is_package_available(package_name):
     try:
-        subprocess.run(['apt-cache', 'show', package_name],
-                       stdout=subprocess.DEVNULL, check=True)
-        return True
+        apt_output = subprocess.check_output(
+            ['apt-cache', '-q', 'show', package_name])
+        # On SteamOS "xdg-desktop-portal-gtk" is recommended by the backported
+        # version of flatpak, even if it is not available in the repositories.
+        # For this reason we also check the apt-cache -q show output before
+        # asserting that a package is really available.
+        return bool(apt_output)
     except (OSError, FileNotFoundError, subprocess.CalledProcessError):
         return False
 
@@ -213,7 +217,7 @@ def choose_xdg_portal_backend(default_backend="xdg-desktop-portal-gtk"):
         return default_backend
     else:
         sys.stderr.write(
-            "There isn't a known XDG portal backend that can be installed")
+            "There isn't a known XDG portal backend that can be installed\n")
         return None
 
 
@@ -480,6 +484,7 @@ def check_config(path, config):
 def main():
     config = {}
     os_release = OsRelease()
+    missing_packages = []    # type: List[str]
 
     parser = argparse.ArgumentParser(description='Install Steam dependencies')
     parser.add_argument(
@@ -562,6 +567,23 @@ def main():
                 packages[package.name] = package
                 dependencies.append([package])
 
+    # Try to install these packages, even if they are not
+    # listed in the steamdeps.txt file. If they are not available we
+    # just inform the user about it and continue.
+    for additional_pkg in (
+        'steam-libs-amd64:amd64',
+        'steam-libs-i386:i386',
+        'xdg-desktop-portal',
+        choose_xdg_portal_backend() or 'xdg-desktop-portal-gtk',
+    ):
+        if additional_pkg not in packages:
+            if is_package_available(additional_pkg):
+                package = Package(additional_pkg, [])
+                packages[package.name] = package
+                dependencies.append([package])
+            else:
+                missing_packages.append(additional_pkg)
+
     # The Steam container runtime (pressure-vessel) requires a setuid
     # bubblewrap executable on some kernel configurations. Steam is
     # unprivileged, so we have to get it from the host OS.
@@ -579,6 +601,14 @@ def main():
         packages[package.name] = package
         dependencies.append([package])
 
+    if missing_packages:
+        print("These packages are not available:\n")
+
+        for p in sorted(missing_packages):
+            print("- %s" % p)
+
+        print("\nThe Steam client may have limited functionality.")
+
     # Print package dependency information for debug
     """
     for row in dependencies:
