@@ -1,5 +1,8 @@
 #!/usr/bin/env bash
 
+# verbose
+#set -x
+
 set -o pipefail
 shopt -s failglob
 set -u
@@ -722,6 +725,7 @@ SEGV_EXITCODE=139
 
 # and launch steam
 STEAM_DEBUGGER=${DEBUGGER-}
+: "${DEBUGGER_ARGS:=}"
 unset DEBUGGER # Don't use debugger if Steam launches itself recursively
 if [ "$STEAM_DEBUGGER" == "gdb" ] || [ "$STEAM_DEBUGGER" == "cgdb" ]; then
 	ARGSFILE=$(mktemp $USER.steam.gdb.XXXX)
@@ -743,8 +747,15 @@ if [ "$STEAM_DEBUGGER" == "gdb" ] || [ "$STEAM_DEBUGGER" == "cgdb" ]; then
 		unset LD_LIBRARY_PATH
 	fi
 
-	echo $STEAM_DEBUGGER -x "$ARGSFILE" --args "$STEAMROOT/$STEAMEXEPATH" "$@"
-	$STEAM_DEBUGGER -x "$ARGSFILE" --args "$STEAMROOT/$STEAMEXEPATH" "$@"
+	# Enable index file caching for reasonable launch time under gdb
+	echo set index-cache on >> "$ARGSFILE"
+	echo show index-cache >> "$ARGSFILE"
+
+	: "${DEBUGGER_ARGS=}"
+	echo "gdb/cgdb launch with ARGSFILE: $ARGSFILE"
+	echo $STEAM_DEBUGGER -x "$ARGSFILE" $DEBUGGER_ARGS --args "$STEAMROOT/$STEAMEXEPATH" "$@"
+
+	$STEAM_DEBUGGER -x "$ARGSFILE" $DEBUGGER_ARGS --args "$STEAMROOT/$STEAMEXEPATH" "$@"
 	rm "$ARGSFILE"
 elif [ "$STEAM_DEBUGGER" == "valgrind" ]; then
 	: "${STEAM_VALGRIND:=}"
@@ -754,8 +765,10 @@ elif [ "$STEAM_DEBUGGER" == "callgrind" ]; then
 elif [ "$STEAM_DEBUGGER" == "strace" ]; then
 	strace -osteam.strace "$STEAMROOT/$STEAMEXEPATH" "$@"
 else
-	echo $STEAM_DEBUGGER "$STEAMROOT/$STEAMEXEPATH" "$@"
-	$STEAM_DEBUGGER "$STEAMROOT/$STEAMEXEPATH" "$@"
+	# Most likely not what you want!
+	echo "WARNING: Using default/fallback debugger launch"
+	echo $STEAM_DEBUGGER $DEBUGGER_ARGS "$STEAMROOT/$STEAMEXEPATH" "$@"
+	$STEAM_DEBUGGER $DEBUGGER_ARGS "$STEAMROOT/$STEAMEXEPATH" "$@"
 fi
 STATUS=$?
 
